@@ -1,19 +1,9 @@
 /*
-** Copyright (C) 2002-2008 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (c) 2002-2016, Erik de Castro Lopo <erikd@mega-nerd.com>
+** All rights reserved.
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+** This code is released under 2-clause BSD license. Please see the
+** file at : https://github.com/erikd/libsamplerate/blob/master/COPYING
 */
 
 #include "config.h"
@@ -22,53 +12,59 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
+#include <assert.h>
+
+#if (HAVE_FFTW3)
+#include <fftw3.h>
+#else
+static inline void
+fftw_cleanup (void)
+{	return ;
+}
+#endif
 
 #include <samplerate.h>
 
 #include "util.h"
-#define	BUFFER_LEN		(1<<15)
+#define	BUFFER_LEN		50000
 #define	BLOCK_LEN		(12)
 
+#define	MAX_CHANNELS	10
+
 static void simple_test (int converter, int channel_count, double target_snr) ;
 static void process_test (int converter, int channel_count, double target_snr) ;
 static void callback_test (int converter, int channel_count, double target_snr) ;
 
 int
 main (void)
-{
+{	double target ;
+	int k ;
+
 	puts ("\n    Zero Order Hold interpolator :") ;
-	simple_test		(SRC_ZERO_ORDER_HOLD, 1, 45.0) ;
-	process_test	(SRC_ZERO_ORDER_HOLD, 1, 45.0) ;
-	callback_test	(SRC_ZERO_ORDER_HOLD, 1, 45.0) ;
-	simple_test		(SRC_ZERO_ORDER_HOLD, 2, 44.0) ;
-	process_test	(SRC_ZERO_ORDER_HOLD, 2, 44.0) ;
-	callback_test	(SRC_ZERO_ORDER_HOLD, 2, 44.0) ;
-	simple_test		(SRC_ZERO_ORDER_HOLD, 3, 44.0) ;
-	process_test	(SRC_ZERO_ORDER_HOLD, 3, 44.0) ;
-	callback_test	(SRC_ZERO_ORDER_HOLD, 3, 44.0) ;
+	target = 38.0 ;
+	for (k = 1 ; k <= 3 ; k++)
+	{	simple_test		(SRC_ZERO_ORDER_HOLD, k, target) ;
+		process_test	(SRC_ZERO_ORDER_HOLD, k, target) ;
+		callback_test	(SRC_ZERO_ORDER_HOLD, k, target) ;
+		} ;
 
 	puts ("\n    Linear interpolator :") ;
-	simple_test		(SRC_LINEAR, 1, 92.0) ;
-	process_test	(SRC_LINEAR, 1, 92.0) ;
-	callback_test	(SRC_LINEAR, 1, 92.0) ;
-	simple_test		(SRC_LINEAR, 2, 90.0) ;
-	process_test	(SRC_LINEAR, 2, 90.0) ;
-	callback_test	(SRC_LINEAR, 2, 90.0) ;
-	simple_test		(SRC_LINEAR, 3, 88.0) ;
-	process_test	(SRC_LINEAR, 3, 88.0) ;
-	callback_test	(SRC_LINEAR, 3, 88.0) ;
+	target = 79.0 ;
+	for (k = 1 ; k <= 3 ; k++)
+	{	simple_test		(SRC_LINEAR, k, target) ;
+		process_test	(SRC_LINEAR, k, target) ;
+		callback_test	(SRC_LINEAR, k, target) ;
+		} ;
 
 	puts ("\n    Sinc interpolator :") ;
-	simple_test		(SRC_SINC_FASTEST, 1, 100.0) ;
-	process_test	(SRC_SINC_FASTEST, 1, 100.0) ;
-	callback_test	(SRC_SINC_FASTEST, 1, 100.0) ;
-	simple_test		(SRC_SINC_FASTEST, 2, 100.0) ;
-	process_test	(SRC_SINC_FASTEST, 2, 100.0) ;
-	callback_test	(SRC_SINC_FASTEST, 2, 100.0) ;
-	simple_test		(SRC_SINC_FASTEST, 3, 100.0) ;
-	process_test	(SRC_SINC_FASTEST, 3, 100.0) ;
-	callback_test	(SRC_SINC_FASTEST, 3, 100.0) ;
+	target = 100.0 ;
+	for (k = 1 ; k <= MAX_CHANNELS ; k++)
+	{	simple_test		(SRC_SINC_FASTEST, k, target) ;
+		process_test	(SRC_SINC_FASTEST, k, target) ;
+		callback_test	(SRC_SINC_FASTEST, k, target) ;
+		} ;
 
+	fftw_cleanup () ;
 	puts ("") ;
 
 	return 0 ;
@@ -77,10 +73,10 @@ main (void)
 /*==============================================================================
 */
 
-static float input_serial		[BUFFER_LEN] ;
-static float input_interleaved	[BUFFER_LEN] ;
-static float output_interleaved	[BUFFER_LEN] ;
-static float output_serial		[BUFFER_LEN] ;
+static float input_serial		[BUFFER_LEN * MAX_CHANNELS] ;
+static float input_interleaved	[BUFFER_LEN * MAX_CHANNELS] ;
+static float output_interleaved	[BUFFER_LEN * MAX_CHANNELS] ;
+static float output_serial		[BUFFER_LEN * MAX_CHANNELS] ;
 
 static void
 simple_test (int converter, int channel_count, double target_snr)
@@ -89,15 +85,17 @@ simple_test (int converter, int channel_count, double target_snr)
 	double	freq, snr ;
 	int		ch, error, frames ;
 
-	printf ("\t%-22s (%d channel%c) ............. ", "simple_test", channel_count, channel_count > 1 ? 's' : ' ') ;
+	printf ("\t%-22s (%2d channel%c) ............ ", "simple_test", channel_count, channel_count > 1 ? 's' : ' ') ;
 	fflush (stdout) ;
 
+	assert (channel_count <= MAX_CHANNELS) ;
+
 	memset (input_serial, 0, sizeof (input_serial)) ;
 	memset (input_interleaved, 0, sizeof (input_interleaved)) ;
 	memset (output_interleaved, 0, sizeof (output_interleaved)) ;
 	memset (output_serial, 0, sizeof (output_serial)) ;
 
-	frames = MIN (ARRAY_LEN (input_serial) / channel_count, 1 << 16) ;
+	frames = BUFFER_LEN ;
 
 	/* Calculate channel_count separate windowed sine waves. */
 	for (ch = 0 ; ch < channel_count ; ch++)
@@ -159,19 +157,21 @@ process_test (int converter, int channel_count, double target_snr)
 	double	freq, snr ;
 	int		ch, error, frames, current_in, current_out ;
 
-	printf ("\t%-22s (%d channel%c) ............. ", "process_test", channel_count, channel_count > 1 ? 's' : ' ') ;
+	printf ("\t%-22s (%2d channel%c) ............ ", "process_test", channel_count, channel_count > 1 ? 's' : ' ') ;
 	fflush (stdout) ;
 
+	assert (channel_count <= MAX_CHANNELS) ;
+
 	memset (input_serial, 0, sizeof (input_serial)) ;
 	memset (input_interleaved, 0, sizeof (input_interleaved)) ;
 	memset (output_interleaved, 0, sizeof (output_interleaved)) ;
 	memset (output_serial, 0, sizeof (output_serial)) ;
 
-	frames = MIN (ARRAY_LEN (input_serial) / channel_count, 1 << 16) ;
+	frames = BUFFER_LEN ;
 
 	/* Calculate channel_count separate windowed sine waves. */
 	for (ch = 0 ; ch < channel_count ; ch++)
-	{	freq = (200.0 + 33.333333333 * ch) / 44100.0 ;
+	{	freq = (400.0 + 11.333333333 * ch) / 44100.0 ;
 		gen_windowed_sines (1, &freq, 1.0, input_serial + ch * frames, frames) ;
 		} ;
 
@@ -285,16 +285,18 @@ callback_test (int converter, int channel_count, double target_snr)
 	double	freq, snr, src_ratio ;
 	int		ch, error, frames, read_total, read_count ;
 
-	printf ("\t%-22s (%d channel%c) ............. ", "callback_test", channel_count, channel_count > 1 ? 's' : ' ') ;
+	printf ("\t%-22s (%2d channel%c) ............ ", "callback_test", channel_count, channel_count > 1 ? 's' : ' ') ;
 	fflush (stdout) ;
 
+	assert (channel_count <= MAX_CHANNELS) ;
+
 	memset (input_serial, 0, sizeof (input_serial)) ;
 	memset (input_interleaved, 0, sizeof (input_interleaved)) ;
 	memset (output_interleaved, 0, sizeof (output_interleaved)) ;
 	memset (output_serial, 0, sizeof (output_serial)) ;
 	memset (&test_callback_data, 0, sizeof (test_callback_data)) ;
 
-	frames = MIN (ARRAY_LEN (input_serial) / channel_count, 1 << 16) ;
+	frames = BUFFER_LEN ;
 
 	/* Calculate channel_count separate windowed sine waves. */
 	for (ch = 0 ; ch < channel_count ; ch++)
